/// @desc Update state
if (state == DEAD) {
  // Nothing happens when dead
  face_dir = DOWN;
} else if (GameController.liftet_inhabitant == id) {
  // Being lifted around
  state = LIFTED;
  face_dir = DOWN;
} else if (!ON_GROUND) {
  // Fall
  state = FALLING;
} else if (state == LIFTED || state == FALLING) {
  // Stop being lifted
  state = IDLE;
  next_state_update = current_time + 1000 + irandom(6000);
} else if (current_time > next_state_update) {
  // Switch between idle and moving
  if (state == IDLE) {
    var _pos = get_new_pos();
    while (point_distance(x, y, _pos[X], _pos[Y]) > 64) {
      _pos = get_new_pos();
    }
    state = MOVING;
    target_x = _pos[X];
    target_y = _pos[Y];
  } else {
    state = IDLE;
  }
  // New update
  next_state_update = current_time + irandom(6000);
}

// Update corona
switch (corona_level) {
  case 0: break;
  case 1: {
    if (DAYS - contraction_point >= 11 || (DAYS - contraction_point >= 2 && irandom(corona_strand / 2) == 13)) {
      corona_level++;
      spread_point = DAYS;
    }
  } break;
  case 5: {
    if (state != DEAD) {
      GameController.deaths++;
      state = DEAD;
      audio_play_sound(choose(snd_dead_1, snd_dead_2), 1, false);
    }
  } break;
  default: {
    // Decrease by immunity
    corona_level = max(2, corona_level - immunity);
    // Evolve
    if (irandom(corona_strand / (corona_level)) == 13) {
      corona_level += .25 + System.difficulty * .25;
    }
    corona_level = min(corona_level, 5);
  };
}

// Healthy again!
if (MY_GROUND == obj_hospital.id && state != DEAD && state != LIFTED && z > -8) {
  var _count = obj_hospital.count;
  var _medicine = min((_count) ? min(obj_hospital.medicine, obj_hospital.level / _count) : 0, 1);
      
  if (_medicine > 0) {
    obj_hospital.medicine -= _medicine;
    if (corona_level >= 2) {
      effect_create_above(ef_flare, x, y + z - 8, 0, c_lime);
    }
    if (corona_level > 2) {
      corona_level = max(2, corona_level - _medicine / 4);
    }
    
    // Good ridance
    if (DAYS - spread_point >= 3 && corona_level == 2 && _medicine >= 1) {
      effect_create_above(ef_ring, x, y + z - 8, 0, c_lime);
      audio_play_sound(snd_healed, 1, false);
      corona_level = 0;
      immunity += .01;
    }
  }
}

// Update limbs
updateLimb(leftHand, x - 8, z + y - 8, 0, 4);
updateLimb(rightHand, x + 8, z + y - 8, 0, 4);
updateLimb(leftFoot, x - 4, z + y - 2, 2, 2);
updateLimb(rightFoot, x + 4, z + y - 2, 2, 2);

if (leftFoot[Y] > y) {
  leftFoot[Y] = y;
}
if (rightFoot[Y] > y) {
  rightFoot[Y] = y;
}

// Update color
color = merge_color(color, mix_color_by_level($c98df6, $aad4b7, corona_level), .1);

// Infect others
if (corona_level >= 2 && place_meeting(x, y, obj_inhabitant)) {
  var _spread_risk = get_spread_risk(corona_strand, corona_level, 4);
  with (instance_place(x, y, obj_inhabitant)) {
    if (corona_level == 0 && abs(z - other.z) <= 17 && irandom(_spread_risk) == 13) {
      corona_level = 1;
      corona_strand = max(100, other.corona_strand - irandom(100));
      contraction_point = DAYS;
    }
  }
}